@@ -2257,7 +2257,7 @@ int send1sms(int device, int modem, int* quick, int* errorcounter)
         stop_if_file_exists("Cannot delete",filename,"","");
 	writelogfile(LOG_INFO, process_title, "Deleted file %s",filename);
       }
-      unlockfile(filename);
+      unlock(filename);
       // Check how often this modem failed and block it if it seems to be broken
       (*errorcounter)++;
       if (*errorcounter>=blockafter)
@@ -2288,7 +2288,7 @@ int send1sms(int device, int modem, int* quick, int* errorcounter)
         stop_if_file_exists("Cannot delete",filename,"","");
 	writelogfile(LOG_INFO, process_title, "Deleted file %s",filename);
       }
-      unlockfile(filename);
+      unlock(filename);
     }
     
 #ifdef DEBUGMSG
